from __future__ import absolute_import
from __future__ import division
from __future__ import print_function

from urllib.request import urlopen as uReq
from bs4 import BeautifulSoup as soup
import argparse
import os
from Yahoo_Finance_Stock_Ticker.ticker import start_ticker
from Yahoo_Finance_Stock_Ticker.ticker import add_ticker
from Yahoo_Finance_Stock_Ticker.ticker import remove_ticker
from Yahoo_Finance_Stock_Ticker.ticker import create_new

def main():
	parser = argparse.ArgumentParser()
	parser.add_argument('--start', help="Print the ticker(s) that is/are saved",choices=['ticker'])
	parser.add_argument('--add', help="Add a stock ticker")
	parser.add_argument('--remove', help="Remove a stock ticker")
	parser.add_argument('--create', help="Create a new list")
	args = parser.parse_args()
	
	if args.add:
		add_ticker(args.add)
	
	if args.remove:
		remove_ticker(args.remove)
	
	if args.start == 'ticker':
		start_ticker()

	if args.create == 'list':
		create_new()

if __name__ == '__main__':
	main()


from __future__ import absolute_import
from __future__ import division
from __future__ import print_function

import os
import requests
from urllib.request import urlopen as uReq
from bs4 import BeautifulSoup as soup
from os import system


def start_ticker():
	system('cls')
	print('%9s  %9s  %9s  %9s  %15s  %15s'%('Ticker','Price','Open','Close','Volume','Ave. Volume'))
	print('-----------------------------------------------------------------------------')
	with open('ticker.txt','r') as f:
		tmp = f.readline()
		for line in f:
			try:
				ticker = line.strip('\n')
				my_url = 'https://finance.yahoo.com/quote/'+ticker+'?p='+ticker
				uClient = uReq(my_url)
				page_html = uClient.read()
				page_soup = soup(page_html,'html.parser')
				curPrice = page_soup.findAll("span",{"class":"Trsdu(0.3s) Fw(b) Fz(36px) Mb(-4px) D(ib)"})
				openPrice = page_soup.findAll("td",{"data-test":"OPEN-value"})
				closePrice = page_soup.findAll("td",{"data-test":"PREV_CLOSE-value"})
				volumn = page_soup.findAll("td",{"data-test":"TD_VOLUME-value"})
				aveVolumn = page_soup.findAll("td",{"data-test":"AVERAGE_VOLUME_3MONTH-value"})
				print('%9s  %9s  %9s  %9s  %15s  %15s'%(ticker,curPrice[0].text,openPrice[0].text,closePrice[0].text,volumn[0].text,aveVolumn[0].text))
			except:
				print(ticker, ': Invalid ticker')
		print()
		pass

def add_ticker(stock):
	with open('ticker.txt','a') as f:
		request = requests.get('https://finance.yahoo.com/quote/'+stock+'?p='+stock)
		if request.status_code == 200:
			f.write('\n'+stock)
		else:
			print('Invalid ticker')


def remove_ticker(stock):
	with open('ticker.txt', 'r') as rf:
		with open('ticker_tmp.txt', 'w') as wf:
			for line in rf:
				curTicker = line.strip('\n')
				print('->',curTicker)
				if stock != curTicker:
					wf.write(curTicker+'\n')
	os.remove('ticker.txt')
	os.rename('ticker_tmp.txt', 'ticker.txt')


def create_new():
	script_dir = os.path.dirname(__file__)
	tickerPath = os.path.join(os.getcwd(),'ticker.txt')
	f = open(tickerPath, 'w')
	f.close()


from setuptools import setup, find_packages

setup(
	name='Yahoo_Finance_Stock_Ticker',
	packages=find_packages(),
	version='0.0.0',
	description='Web scrapping on Yahoo Finance for stock market prices',
	url='https://github.com/PizzaPat/Yahoo_Finance_Stock_Ticker',
	author='Patrapee Pongtana',
	author_email='patpongtana@gmail.com',
	license='MIT',
	keywords=['yh-ticker'],
	entry_points={
		'console_scripts':[
			'yh-ticker=Yahoo_Finance_Stock_Ticker.main:main'
			]},
	install_requires=['bs4','argparse']
	)